Double-quotes rewritten to single-quotes
[mailer.git] / index.php
index 9d61748040789a81eec21cfd61263ca3a1ff4d9b..ec9080300da8eefcb9fe4549224ff9e68c907cad 100644 (file)
--- a/index.php
+++ b/index.php
@@ -4,7 +4,7 @@ define('DEVELOPER', true);
 //xdebug_start_trace();
 /**
  * The main class with the entry point to the whole application. This class
- * "emulates" Java(tm)'s entry point call. Additionally it covers local
+ * "emulates" Java's entry point call. Additionally it covers local
  * variables from outside access to prevent possible attacks on uninitialized
  * local variables.
  *
@@ -49,12 +49,13 @@ class ApplicationEntryPoint {
        /**
         * The application's emergency exit
         *
* @param       $message        The optional message we shall output on exit
* @param       $code           Error code from exception
* @param       $extraData      Extra information from exceptions
         * @return      void
         */
-       public static function app_die ($message = "", $code = false, $extraData = "") {
+       public static function app_die ($message = "", $code = false, $extraData = "", $silentMode = false) {
                // Is this method already called?
                if (defined('EMERGENCY_EXIT_CALLED')) {
                        // Then output the text directly
@@ -68,24 +69,32 @@ class ApplicationEntryPoint {
                if (empty($message)) {
                        // No message provided
                        $message = "No message provided!";
-               }
+               } // END - if
+
+               // Get config instance
+               $configInstance = FrameworkConfiguration::getInstance();
+
+               // Do we have debug installation?
+               if (($configInstance->readConfig('product_install_mode') == "productive") || ($silentMode === true)) {
+                       // Abort here
+                       die();
+               } // END - if
 
                // Get some instances
                $tpl = FrameworkConfiguration::getInstance()->readConfig('template_class');
                $lang = LanguageSystem::getInstance();
-               $io = FileIoHandler::getInstance();
 
                // Get response instance
                $responseInstance = ApplicationHelper::getInstance()->getResponseInstance();
 
                // Is the template engine loaded?
-               if ((class_exists($tpl)) && (is_object($lang)) && (is_object($io))) {
+               if ((class_exists($tpl)) && (is_object($lang))) {
                        // Use the template engine for putting out (nicer look) the message
                        try {
                                // Get the template instance from our object factory
-                               $templateInstance = ObjectFactory::createObjectByName($tpl, array(FrameworkConfiguration::getInstance()->readConfig('tpl_base_path'), $lang, $io));
+                               $templateInstance = ObjectFactory::createObjectByName($tpl, array(ApplicationHelper::getInstance()));
                        } catch (FrameworkException $e) {
-                               die(sprintf("[Main:] Could not initialize template engine for reason: <strong>%s</strong>",
+                               die(sprintf("[Main:] Could not initialize template engine for reason: <span class=\"exception_reason\">%s</span>",
                                        $e->getMessage()
                                ));
                        }
@@ -93,13 +102,25 @@ class ApplicationEntryPoint {
                        // Get and prepare backtrace for output
                        $backtraceArray = debug_backtrace();
                        $backtrace = "";
-                       foreach ($backtraceArray as $key=>$trace) {
+                       foreach ($backtraceArray as $key => $trace) {
                                if (!isset($trace['file'])) $trace['file'] = __FILE__;
                                if (!isset($trace['line'])) $trace['line'] = __LINE__;
                                if (!isset($trace['args'])) $trace['args'] = array();
                                $backtrace .= "<span class=\"backtrace_file\">".basename($trace['file'])."</span>:".$trace['line'].", <span class=\"backtrace_function\">".$trace['function']."(".count($trace['args']).")</span><br />";
                        } // END - foreach
 
+                       // Init application instance
+                       $appInstance = null;
+
+                       // Is the class there?
+                       if (class_exists('ApplicationHelper')) {
+                               // Get application instance
+                               $appInstance = ApplicationHelper::getInstance();
+
+                               // Assign application data
+                               $templateInstance->assignApplicationData($appInstance);
+                       } // END - if
+
                        // Assign variables
                        $templateInstance->assignVariable('message', $message);
                        $templateInstance->assignVariable('code', $code);
@@ -138,25 +159,22 @@ class ApplicationEntryPoint {
         * The application's main entry point. This class isolates some local
         * variables which shall not become visible to outside because of security
         * concerns. We are doing this here to "emulate" the well-known entry
-        * point in Java(tm).
+        * point in Java.
         *
         * @return      void
         */
        public static function main () {
-               // Some non-global common arrays we need...
-               global $_SERVER;
-
                // Load config file
                require(dirname(__FILE__) . '/inc/config.php');
 
                // Load all include files
-               require(PATH . 'inc/includes.php');
+               require($cfg->readConfig('base_path') . 'inc/includes.php');
 
                // Load all framework classes
-               require(PATH . 'inc/classes.php');
+               require($cfg->readConfig('base_path') . 'inc/classes.php');
 
                // Include the application selector
-               require(PATH . 'inc/selector.php');
+               require($cfg->readConfig('base_path') . 'inc/selector.php');
        } // END - main()
 
 } // END - class
@@ -49,12 +49,13 @@ class ApplicationEntryPoint {
         * The application's emergency exit
         *
-        * @param       $message        The optional message we shall output on exit
-        * @param       $code           Error code from exception
-        * @param       $extraData      Extra information from exceptions
+        * @param       $message                The optional message we shall output on exit
+        * @param       $code                   Error code from exception
+        * @param       $extraData              Extra information from exceptions
+        * @param       $silentMode             Wether not silent mode is turned on
         * @return      void
         */